@@ -409,6 +409,10 @@ class StreamResponse(HeadersMixin):
             value = cookie.output(header='')[1:]
             self.headers.add('Set-Cookie', value)
 
+    @property
+    def started(self):
+        return self._resp_impl is not None
+
     @property
     def status(self):
         return self._status
@@ -1206,8 +1210,9 @@ class RequestHandler(ServerHttpProtocol):
 
             if not isinstance(resp, StreamResponse):
                 raise RuntimeError(
-                    ("Handler should return response instance, got {!r}")
-                    .format(type(resp)))
+                    ("Handler {!r} should return response instance, got {!r} "
+                     "[middlewares {!r}]")
+                    .format(match_info.handler, type(resp), self._middlewares))
         except HTTPException as exc:
             resp = exc
 
