@@ -48,14 +48,17 @@ class HttpClientFunctionalTests(unittest.TestCase):
                 self.assertEqual(content1, content2)
                 r.close()
 
-    def test_client_HTTP_200_OK_METHOD(self):
+    def test_HTTP_200_OK_METHOD_connector(self):
         with test_utils.run_server(self.loop, router=Functional) as httpd:
-            for meth in ('get', 'post', 'put', 'delete', 'head'):
-                host = httpd.url().split('://', 1)[-1]
-                httpclient = client.HttpClient(host, loop=self.loop)
+            conn = aiohttp.TCPConnector(
+                conn_timeout=0.2, resolve=True, loop=self.loop)
+            conn.clear_resolved_hosts()
 
+            for meth in ('get', 'post', 'put', 'delete', 'head'):
                 r = self.loop.run_until_complete(
-                    httpclient.request(meth, '/method/%s' % meth))
+                    client.request(
+                        meth, httpd.url('method', meth),
+                        connector=conn, loop=self.loop))
                 content1 = self.loop.run_until_complete(r.read())
                 content2 = self.loop.run_until_complete(r.read())
                 content = content1.decode()
@@ -68,64 +71,6 @@ class HttpClientFunctionalTests(unittest.TestCase):
                 self.assertEqual(content1, content2)
                 r.close()
 
-    def test_client_HTTP_200_OK_METHOD_no_conn_pool(self):
-        with test_utils.run_server(self.loop, router=Functional) as httpd:
-            for meth in ('get', 'post', 'put', 'delete', 'head'):
-                host = httpd.url().split('://', 1)[-1]
-                httpclient = client.HttpClient(
-                    host, loop=self.loop, conn_pool=False)
-
-                r = self.loop.run_until_complete(
-                    httpclient.request(meth, '/method/%s' % meth))
-                content1 = self.loop.run_until_complete(r.read())
-                content2 = self.loop.run_until_complete(r.read())
-                content = content1.decode()
-
-                self.assertEqual(r.status, 200)
-                if meth == 'head':
-                    self.assertEqual(b'', content1)
-                else:
-                    self.assertIn('"method": "%s"' % meth.upper(), content)
-                self.assertEqual(content1, content2)
-                r.close()
-
-    def test_client_HTTP_200_OK_METHOD_no_resolve(self):
-        with test_utils.run_server(self.loop, router=Functional) as httpd:
-            for meth in ('get', 'post', 'put', 'delete', 'head'):
-                host = httpd.url().split('://', 1)[-1]
-                httpclient = client.HttpClient(
-                    host, loop=self.loop, resolve=False)
-
-                r = self.loop.run_until_complete(
-                    httpclient.request(meth, '/method/%s' % meth))
-                content1 = self.loop.run_until_complete(r.read())
-                content2 = self.loop.run_until_complete(r.read())
-                content = content1.decode()
-
-                self.assertEqual(r.status, 200)
-                if meth == 'head':
-                    self.assertEqual(b'', content1)
-                else:
-                    self.assertIn('"method": "%s"' % meth.upper(), content)
-                self.assertEqual(content1, content2)
-                r.close()
-
-    def test_client_defaults_HTTP_200_OK_METHOD(self):
-        with test_utils.run_server(self.loop, router=Functional) as httpd:
-            host = httpd.url().split('://', 1)[-1]
-            httpclient = client.HttpClient(
-                host, method='GET', path='/method/get', loop=self.loop)
-
-            r = self.loop.run_until_complete(httpclient.request())
-            content1 = self.loop.run_until_complete(r.read())
-            content2 = self.loop.run_until_complete(r.read())
-            content = content1.decode()
-
-            self.assertEqual(r.status, 200)
-            self.assertIn('"method": "GET"', content)
-            self.assertEqual(content1, content2)
-            r.close()
-
     def test_HTTP_200_OK_METHOD_ssl(self):
         connector = aiohttp.TCPConnector(verify_ssl=False, loop=self.loop)
 
@@ -829,7 +774,7 @@ class HttpClientFunctionalTests(unittest.TestCase):
             self.assertIn(b'"Cookie": "test1=123; test3=456"', bytes(content))
             r.close()
 
-    @mock.patch('aiohttp.client.client_log')
+    @mock.patch('aiohttp.client.client_logger')
     def test_set_cookies(self, m_log):
         with test_utils.run_server(self.loop, router=Functional) as httpd:
             resp = self.loop.run_until_complete(
@@ -879,22 +824,21 @@ class HttpClientFunctionalTests(unittest.TestCase):
                 client.request('get', httpd.url('broken'), loop=self.loop))
             self.assertEqual(r.status, 200)
             self.assertRaises(
-                aiohttp.IncompleteRead,
+                aiohttp.ServerDisconnectedError,
                 self.loop.run_until_complete, r.json())
             r.close()
 
     def test_request_conn_error(self):
         self.assertRaises(
-            aiohttp.ConnectionError,
+            aiohttp.ClientConnectionError,
             self.loop.run_until_complete,
-            client.request('get', 'http://0.0.0.0:1',
-                           loop=self.loop))
+            client.request('get', 'http://0.0.0.0:1', loop=self.loop))
 
     def test_request_conn_closed(self):
         with test_utils.run_server(self.loop, router=Functional) as httpd:
             httpd['close'] = True
             self.assertRaises(
-                aiohttp.ClientConnectionError,
+                aiohttp.ClientHttpProcessingError,
                 self.loop.run_until_complete,
                 client.request(
                     'get', httpd.url('method', 'get'), loop=self.loop))
@@ -945,7 +889,7 @@ class HttpClientFunctionalTests(unittest.TestCase):
 
         conn.close()
 
-    @mock.patch('aiohttp.client.client_log')
+    @mock.patch('aiohttp.client.client_logger')
     def test_session_cookies(self, m_log):
         from aiohttp import connector
         conn = connector.TCPConnector(share_cookies=True, loop=self.loop)
@@ -1102,9 +1046,7 @@ class HttpClientFunctionalTests(unittest.TestCase):
             yield from r.read()
             self.assertEqual(1, len(connector._conns))
 
-            with self.assertRaisesRegex(
-                    aiohttp.ClientConnectionError,
-                    'Connection closed by server'):
+            with self.assertRaises(aiohttp.ClientError):
                 yield from client.request('GET', url,
                                           connector=connector,
                                           loop=self.loop)
@@ -1215,5 +1157,5 @@ class Functional(test_utils.Router):
 
         self._response(
             resp,
-            body=json.dumps({'t': (b'0'*1024).decode('utf-8')}),
+            body=json.dumps({'t': (b'0' * 1024).decode('utf-8')}),
             write_body=write_body)
