@@ -255,3 +255,48 @@ class TestUrlDispatcher(unittest.TestCase):
                                name='name')
         self.assertRegex(repr(self.router['name']),
                          r"<StaticRoute 'name' \[GET\] /get/")
+
+    def test_static_adds_slash(self):
+        route = self.router.add_static('/prefix',
+                                       os.path.dirname(aiohttp.__file__))
+        self.assertEqual('/prefix/', route._prefix)
+
+    def test_static_dont_add__double_slash(self):
+        route = self.router.add_static('/prefix/',
+                                       os.path.dirname(aiohttp.__file__))
+        self.assertEqual('/prefix/', route._prefix)
+
+    def test_add_route_with_re(self):
+        handler = asyncio.coroutine(lambda req: Response(req))
+        self.router.add_route('GET', r'/handler/{to:\d+}', handler)
+
+        req = self.make_request('GET', '/handler/1234')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual({'to': '1234'}, info)
+
+    def test_add_route_with_re_not_match(self):
+        handler = asyncio.coroutine(lambda req: Response(req))
+        self.router.add_route('GET', r'/handler/{to:\d+}', handler)
+
+        req = self.make_request('GET', '/handler/tail')
+        with self.assertRaises(HTTPNotFound):
+            self.loop.run_until_complete(self.router.resolve(req))
+
+    def test_add_route_with_re_including_slashes(self):
+        handler = asyncio.coroutine(lambda req: Response(req))
+        self.router.add_route('GET', r'/handler/{to:.+}/tail', handler)
+
+        req = self.make_request('GET', '/handler/re/with/slashes/tail')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual({'to': 're/with/slashes'}, info)
+
+    def test_add_route_with_invalid_re(self):
+        handler = asyncio.coroutine(lambda req: Response(req))
+        with self.assertRaises(ValueError) as ctx:
+            self.router.add_route('GET', r'/handler/{to:+++}', handler)
+        self.assertEqual(
+            "Bad pattern '/handler/(?P<to>+++)': nothing to repeat",
+            str(ctx.exception))
+        self.assertIsNone(ctx.exception.__cause__)
